/**
 *
 *  @version 1.00 
 *  @author Raju Pallath
 *
 *  TESTID 
 * 
 *  Tests out the Element->setAttributeNode(Attribute) method.
 *
 */
package org.mozilla.dom.test;

import java.util.*;
import java.io.*;
import org.mozilla.dom.test.*;
import org.mozilla.dom.*;
import org.w3c.dom.*;

public class BWElement_SetAttributeNode extends BWBaseTest implements Execution
{

   /**
    *
    ***********************************************************
    *  Constructor
    ***********************************************************
    *
    */
   public BWElement_SetAttributeNode()
   {
   }


   /**
    *
    ***********************************************************
    *  Starting point of application
    *
    *  @param   args    Array of command line arguments
    *
    ***********************************************************
    */
   public static void main(String[] args)
   {
   }

   /**
    ***********************************************************
    *
    *  Execute Method 
    *
    *  @param   tobj    Object reference (Node/Document/...)
    *  @return          true or false  depending on whether test passed or failed.
    *
    ***********************************************************
    */
   public boolean execute(Object tobj)
   {
      if (tobj == null)  {
           TestLoader.logPrint("Object is NULL...");
           return BWBaseTest.FAILED;
      }

      String os = System.getProperty("OS");
      osRoutine(os);

      Document d = (Document)tobj;
      if (d != null)
      {
         String nodename="HEAD";
         String attrname="TARGET";
         String attrvalue="dummyWin";
         String aelement="BASE";
	 if (!(setAttributeNode(d, nodename, attrname, attrvalue, aelement)))
	 {
             System.out.println("Set Attribute Node failed...");
             return BWBaseTest.PASSED;
	 }
      } else {
             System.out.println("Document is  NULL..");
             return BWBaseTest.FAILED;
      }

      return BWBaseTest.PASSED;
   }

  /**
   ********************************************************************
   *  Creates an Element, sets it as child of given node and then
   *  Set Attribute Node for that element
   * 
   * @params  doc         Root Document Reference
   * @params  nodename    Node Name for which attribute is being set
   * @params  attrname    Attribute Name of the node whose value is
   *                      going to be set
   * @params  attrvalue   Attribute Value to be set 
   *
   ********************************************************************
   */
  private boolean setAttributeNode(Document doc, String nodeName, String attrName, 
                            String attrValue, String aelement)
  {

         if ((doc == null) || (nodeName == null) || (attrName == null) ||
             (attrValue == null)) return false;

	 if (doc != null)
	 {
              Attr a = doc.createAttribute(attrName);
              if (a == null) {
	         System.out.println("Could not create Attribute " + attrName);
                 return false;
              }

              Element e = doc.createElement(aelement);
              if (e != null)
              {
                  a.setValue(attrValue);
                  e.setAttributeNode(a);
              } else {
	         System.out.println("Element " + aelement + " could not be created...");
                 return false;
              }

              NodeList nl = doc.getElementsByTagName(nodeName);
              if (nl != null) 
              {
                 Node n = nl.item(0);
		 if ( n != null)
		 {
                    n.appendChild(e);
                 }
              } else {
                System.out.println(" Could not find node " + nodeName);
                return false;
              } 
         }
         return true;
   }


   /**
    *
    ***********************************************************
    *  Routine where OS specific checks are made. 
    *
    *  @param   os      OS Name (SunOS/Linus/MacOS/...)
    ***********************************************************
    *
    */
   private void osRoutine(String os)
   {
     if(os == null) return;

     os = os.trim();
     if(os.compareTo("SunOS") == 0) {}
     else if(os.compareTo("Linux") == 0) {}
     else if(os.compareTo("Windows") == 0) {}
     else if(os.compareTo("MacOS") == 0) {}
     else {}
   }
}
