/* 
The contents of this file are subject to the Mozilla Public License
Version 1.0 (the "License"); you may not use this file except in
compliance with the License. You may obtain a copy of the License at
http://www.mozilla.org/MPL/

Software distributed under the License is distributed on an "AS IS"
basis, WITHOUT WARRANTY OF ANY KIND, either express or implied. See
the License for the specific language governing rights and limitations
under the License.

The Initial Developer of the Original Code is Sun Microsystems,
Inc. Portions created by Sun are Copyright (C) 1999 Sun Microsystems,
Inc. All Rights Reserved. 
*/

package org.mozilla.dom;

import java.io.FileOutputStream;
import java.io.BufferedOutputStream;
import java.io.PrintStream;
import java.io.IOException;

import org.w3c.dom.Document;
import org.w3c.dom.DocumentType;
import org.w3c.dom.Element;
import org.w3c.dom.NamedNodeMap;
import org.w3c.dom.Node;
import org.w3c.dom.NodeList;

import org.mozilla.dom.test.*;

public class DOMFactory implements DocumentLoadListener {

  private static final boolean debug = false;

  public DocumentLoadListener getDocumentLoadListener() {
    return this;
  }

  public void startURLLoad(String url, String contentType) {
    if (debug)
      System.err.println("DOM: start URL load - " + 
			 url.toString() + " " + 
			 contentType);
  }

  public void endURLLoad(String url, int status, Document doc) {

    BWStaticDoc.setParentDoc(doc);

    if (debug)
      System.err.println("DOM: end URL load - " + 
			 url.toString() + " " +
			 Integer.toHexString(status));

    if (url.endsWith(".xul") || 
	url.endsWith(".js") || 
	url.endsWith(".css") || 
	url.startsWith("file:")) return;

    Object obj = (Object) doc;

    int returnType = 0;
    TestLoader tl = new TestLoader(obj, returnType);
    if (tl != null) {
       Object reObj = tl.loadTest();
    }
    
    doc = null;
  }

  public void progressURLLoad(String url, int progress, int progressMax) {
    if (debug)
      System.err.println("DOM: progress URL load - " + 
			 url.toString() + " " +
			 Integer.toString(progress) + "/" +
			 Integer.toString(progressMax));
  }

  public void statusURLLoad(String url, String message) {
    if (debug)
      System.err.println("DOM: status URL load - " + 
			 url.toString() + " (" +
			 message + ")");
  }

  public void startDocumentLoad(String url) {
    if (debug)
      System.err.println("DOM: start load - " + 
			 url.toString());
  }

  public void endDocumentLoad(String url, int status) {
    if (debug) {
      System.err.println("DOM: end load - " + 
			 url.toString() + " " + 
			 Integer.toHexString(status));
    } 
  }

}
